==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/firewall/translations/firewall_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation>Cortafuegos</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Sintaxis de notificación</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - uin, %m - mensaje</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Buscar persona desconocida en el directorio y mostrar la ventana con sus datos personales.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Protección de conversaciones desconocidas</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Ignorar conferencias con todas las personas desconocidas</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Proteger contra conversaciones con personas desconocidas</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Pregunta automática</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Enviar confirmación</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Envío seguro</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Habilitar envío seguro</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Debe confirmar cada mensaje enviado a estas personas</translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation>El mensaje fue filtrado</translation>
    </message>
    <message>
        <source>Anonymous chat attempt</source>
        <translation>Intento de conversación anónima</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in history</source>
        <translation>Guardar intento de conversación anónima en el historial</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in log file</source>
        <translation>Guardar intento de conversación anónima en el archivo de registro</translation>
    </message>
    <message>
        <source>Log file path</source>
        <translation>Ruta del archivo de registro</translation>
    </message>
    <message>
        <source>Kadu will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation>Kadu hará la pregunta escrita a continuación, si alguien quiere hablar con usted y usted no los tiene en su lista.</translation>
    </message>
    <message>
        <source>Drop chats with unknown person when I am invisible/unavailable</source>
        <translation>Dejar conversaciones con persona desconocida cuando estoy invisible/ausente</translation>
    </message>
    <message>
        <source>Reaction on right answer</source>
        <translation>Reacción a la respuesta correcta</translation>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation>Yo quiero algo</translation>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>¡ataque de inundación DoS con emoticonos!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>¡ataque de inundación DoS!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Conversación con anónimo abandonada en silencio.
</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK, ahora saluda, y presentate ;-)</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>¡El usuario escribió la respuesta correcta!
</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>!Este mensaje ha sido generado AUTOMÁTICAMENTE!

Soy una persona muy ocupada y no tengo tiempo para estupidas conversaciones. Encuentre a otra persona con quien hablar. Si REALMENTE quiere algo de mí, escriba &quot;Quiero algo&quot; (mayúscula no importa)</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>¿Seguro que desea enviar este mensaje?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sí</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Si y permitir hasta que la conversación cierre</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u escribe</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation>!Este mensaje ha sido generado AUTOMATICÁMENTE!

Soy una persona muy ocupada y no tengo tiempo para estupidas conversaciones con las personas ocultándose. Si quiere hablar conmigo cambie el estado a En línea u Ocupado primero.</translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation>Conversación con anónimo invisible ignorada.
</translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation>      FECHA Y HORA      ::   ID      :: MENSAJE
</translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation>Mover a &apos;Asegurado&apos;</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation>Mover a &apos;Todos&apos;</translation>
    </message>
    <message>
        <source>Secured</source>
        <translation>Asegurado</translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation>Este mensaje será enviado a la persona desconocida.</translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation>Respuesta correcta para la pregunta anterior - puede usar expresiones regulares.</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mensaje:</translation>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation>El mensaje fue bloqueado</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u escribe</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/firewall/translations/firewall_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation>Cortafuegos</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Sintaxis de notificación</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - uin, %m - mensaje</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Buscar persona desconocida en el directorio y mostrar la ventana con sus datos personales.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Protección de conversaciones desconocidas</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Ignorar conferencias con todas las personas desconocidas</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Proteger contra conversaciones con personas desconocidas</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Pregunta automática</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Enviar confirmación</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Envío seguro</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Habilitar envío seguro</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Debe confirmar cada mensaje enviado a estas personas</translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation>El mensaje fue filtrado</translation>
    </message>
    <message>
        <source>Anonymous chat attempt</source>
        <translation>Intento de conversación anónima</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in history</source>
        <translation>Guardar intento de conversación anónima en el historial</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in log file</source>
        <translation>Guardar intento de conversación anónima en el archivo de registro</translation>
    </message>
    <message>
        <source>Log file path</source>
        <translation>Ruta del archivo de registro</translation>
    </message>
    <message>
        <source>Kadu will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation>Kadu hará la pregunta escrita a continuación, si alguien quiere hablar con usted y usted no los tiene en su lista.</translation>
    </message>
    <message>
        <source>Drop chats with unknown person when I am invisible/unavailable</source>
        <translation>Dejar conversaciones con persona desconocida cuando estoy invisible/ausente</translation>
    </message>
    <message>
        <source>Reaction on right answer</source>
        <translation>Reacción a la respuesta correcta</translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation>Mover a &apos;Asegurado&apos;</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation>Mover a &apos;Todos&apos;</translation>
    </message>
    <message>
        <source>Secured</source>
        <translation>Asegurado</translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation>Este mensaje será enviado a la persona desconocida.</translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation>Respuesta correcta para la pregunta anterior - puede usar expresiones regulares.</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mensaje:</translation>
    </message>
</context>
<context>
    <name>FirewallMessageFilter</name>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>¡ataque de inundación DoS con emoticonos!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>¡ataque de inundación DoS!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Conversación con anónimo abandonada en silencio.
</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation>!Este mensaje ha sido generado AUTOMATICÁMENTE!

Soy una persona muy ocupada y no tengo tiempo para estupidas conversaciones con las personas ocultándose. Si quiere hablar conmigo cambie el estado a En línea u Ocupado primero.</translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation>Conversación con anónimo invisible ignorada.
</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>¡El usuario escribió la respuesta correcta!
</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>¿Seguro que desea enviar este mensaje?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sí</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Si y permitir hasta que la conversación cierre</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation>      FECHA Y HORA      ::   ID      :: MENSAJE
</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK, ahora saluda, y presentate ;-)</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>!Este mensaje ha sido generado AUTOMÁTICAMENTE!

Soy una persona muy ocupada y no tengo tiempo para estupidas conversaciones. Encuentre a otra persona con quien hablar. Si REALMENTE quiere algo de mí, escriba &quot;Quiero algo&quot; (mayúscula no importa)</translation>
    </message>
    <message>
        <source>I want something</source>
        <translation>Yo quiero algo</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u escribe</translation>
    </message>
</context>
<context>
    <name>FirewallNotificationService</name>
    <message>
        <source>Message was blocked</source>
        <translation>El mensaje fue bloqueado</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u escribe</translation>
    </message>
</context>
</TS>
